<template>
  <div class="app-container">
    <div class="search_form">
      <div>
        <span class="search_title">客户名称：</span>
        <el-input v-model="searchForm.searchText" style="width: 240px" placeholder="输入客户名称搜索"
                  @change="handleQuery" clearable :prefix-icon="Search" />
        <el-button type="primary" @click="handleQuery" style="margin-left: 10px">搜索</el-button>
      </div>
    </div>
    <div class="table_list">
      <PIMTable :column="tableColumn" :tableData="tableData" :page="page" :isSelection="true"
                :isShowSummary="isShowSummarySon"
                :summaryMethod="summarizeMainTable1"
                :handleSelectionChange="handleSelectionChange" :tableLoading="tableLoading" @pagination="pagination"
                :total="total"></PIMTable>
    </div>
  </div>
</template>

<script setup>
import { ref } from 'vue'
import { Search } from "@element-plus/icons-vue";
import {
  receiptPaymentHistoryListPage
} from "@/api/salesManagement/receiptPayment.js";
const { proxy } = getCurrentInstance()
const tableColumn = ref([
  {
    label: '回款日期',
    prop: 'receiptPaymentDate',
  },
  {
    label: '客户名称',
    prop: 'customerName',
  },
  {
    label: '回款金额',
    prop: 'receiptPaymentAmount',
    formatData: (params) => {
      return parseFloat(params).toFixed(2);
    }
  },
  {
    label: '回款方式',
    prop: 'receiptPaymentType',
    dataType: 'tag',
    formatData: (params) => {
      if (params == 0) {
        return '电汇';
      } else if (params == 1) {
        return '承兑';
      } else {
        return null
      }
    },
    formatType: (params) => {
      return "info"
    }
  },
  {
    label: '登记人',
    prop: 'registrant'
  },
  {
    label: '登记日期',
    prop: 'createTime'
  }
])
const tableData = ref([])
const selectedRows = ref([])
const tableLoading = ref(false)
const page = reactive({
  current: 1,
  size: 100,
})
const total = ref(0)
const data = reactive({
  searchForm: {
    searchText: '',
  },
})
const { searchForm } = toRefs(data)
const { receipt_payment_type } = proxy.useDict("receipt_payment_type")
const isShowSummarySon = ref(true);
// 查询列表
/** 搜索按钮操作 */
const handleQuery = () => {
  page.current = 1
  getList()
}
const pagination = (obj) => {
  page.current = obj.page;
  page.size = obj.limit;
  getList()
}
const getList = () => {
  tableLoading.value = true
  receiptPaymentHistoryListPage({ ...searchForm.value, ...page }).then(res => {
    tableLoading.value = false
    tableData.value = res.records
    total.value = res.total
  })
}
// 子表合计方法
const summarizeMainTable1 = (param) => {
  return proxy.summarizeTable(param, ['receiptPaymentAmount'], {
    ticketsNum: { noDecimal: true }, // 不保留小数
    futureTickets: { noDecimal: true }, // 不保留小数
  });
};
// 表格选择数据
const handleSelectionChange = (selection) => {
  selectedRows.value = selection
}
getList()
</script>

<style scoped lang="scss"></style>
